#/bin/bash
export TERM="dumb"

# clear the screen
clear

# Mirror/Share declarations
export _4D_mirror_server="Server"
export _4D_mirror_share="Share"
export _4D_mirror_user="SomeUser"
export _4D_mirror_password="myPassw0rd"
export _4D_mirror_mount_type="smbfs"


# file path declarations
export _4D_mirror_path="/to/4D_Mac/"
export _4D_installation_path=${HOME}"/Applications/4D/"
export _4D_temp_mount_folder=${HOME}"/4D_temp/"
export _4D_admin_log_osx=${HOME}"/4D_admin.log"
export _4D_mirror_log_osx=${HOME}"/4D_mirror.log"


# message declarations
export msg_mirror_unavail="The 4D mirror is unavailable - please contact MIS"
export msg_create_install_dir="Creating 4D installation directory"
export msg_create_temp_dir="Creating 4D temp directory"
export msg_couldnt_create_temp="Could not create the 4D temp directory - please contact MIS"
export msg_coundnt_create_install="Could not create the 4D installation path - please contact MIS"
export msg_install_dir_exists="4D installation directory exists, moving on"
export msg_temp_dir_exists="4D temp directory exists, moving on"
export msg_mounting_share="Mounting 4D mirror into temp directory"
export msg_sync_started="Synchronizing 4D application; please be patient this may take a few minutes..."
export msg_unmount_share="Unmounting the 4D share"
export msg_remove_temp_dir="Removing the 4D temp directory"
export msg_log_sync_start="sync started at: "
export msg_log_sync_end="sync finished at: "



# below if the string used for appending both stdout and stderr to the _4D_admin_log_osx
# 2>&1 >> ${_4D_admin_log_osx}


# initialize the log
echo -ne $msg_log_sync_start > ${_4D_admin_log_osx}
date 2>&1 >> ${_4D_admin_log_osx} 


# check if install directory exists, if not then create it
if [ ! -d $_4D_installation_path ]
then
	# create the install dir
	echo $msg_create_install_dir 
	echo $msg_create_install_dir 2>&1 >> ${_4D_admin_log_osx}
	mkdir -p $_4D_installation_path 2>&1 >> ${_4D_admin_log_osx}
	if [ ! -d $_4D_installation_path ]
	then
		# could create install dir
		echo $msg_coundnt_create_install 
		echo $msg_coundnt_create_install 2>&1 >> ${_4D_admin_log_osx}
		exit 1
	fi
else
	# install dir already exists
	echo $msg_install_dir_exists 
	echo $msg_install_dir_exists 2>&1 >> ${_4D_admin_log_osx}
fi



# check if temp directory exists, if not then create it
if [ ! -d $_4D_temp_mount_folder ]
then
	# create temp dir use for mounting the mirror
	echo $msg_create_temp_dir 
	echo $msg_create_temp_dir 2>&1 >> ${_4D_admin_log_osx}
	mkdir -p $_4D_temp_mount_folder 2>&1 >> ${_4D_admin_log_osx}
else
	# temp dir already exists
	echo $msg_temp_dir_exists 
	echo $msg_temp_dir_exists 2>&1 >> ${_4D_admin_log_osx}
fi


# check if temp directory exists, if not then report error, if so mount the mirror into it
if [ -d $_4D_temp_mount_folder ]
then
	# mount the mirror share into the temp dir
	echo $msg_mounting_share 
	echo $msg_mounting_share 2>&1 >> ${_4D_admin_log_osx}
	mount -r -t $_4D_mirror_mount_type //${_4D_mirror_user}:${_4D_mirror_password}@${_4D_mirror_server}/${_4D_mirror_share} $_4D_temp_mount_folder 2>&1 >> ${_4D_admin_log_osx}
else
	# could not create temp directory
	echo $msg_couldnt_create_temp 
	echo $msg_couldnt_create_temp 2>&1 >> ${_4D_admin_log_osx}
	exit 1
fi


# check if mirror is mounted and 4D is avail
if [ -d ${_4D_temp_mount_folder}${_4D_mirror_path}4D.app/Contents ]
then
	# start the sync
	echo $msg_sync_started
	echo $msg_sync_started 2>&1 >> ${_4D_admin_log_osx}
	rsync -avzi --delete --log-file=${_4D_mirror_log_osx} ${_4D_temp_mount_folder}${_4D_mirror_path} $_4D_installation_path 2>&1 >> ${_4D_admin_log_osx}

	# open 4D
	open -a ${_4D_installation_path}/4D.app 2>&1 >> ${_4D_admin_log_osx}
else
	# mirror is unavail
	echo $msg_mirror_unavail
	echo $msg_mirror_unavail 2>&1 >> ${_4D_admin_log_osx}
fi

	
# unmount the share
echo $msg_unmount_share
echo $msg_unmount_share 2>&1 >> ${_4D_admin_log_osx}
umount $_4D_temp_mount_folder 2>&1 >> ${_4D_admin_log_osx}

# remove the temp directory
echo $msg_remove_temp_dir
echo $msg_remove_temp_dir 2>&1 >> ${_4D_admin_log_osx}
rmdir $_4D_temp_mount_folder 2>&1 >> ${_4D_admin_log_osx}

# close the log
echo -ne $msg_log_sync_end >> ${_4D_admin_log_osx}
date 2>&1 >> ${_4D_admin_log_osx} 
