@ECHO OFF

rem clear screen
CLS

REM general message declarations
set "msg_4D_GetNew4D=Starting update of 4D Client App; please be patient, this may take a few minutes."
set "msg_4D_GetNew4Dfinished=Finsished update of 4D Client App; thank you for your patience."
set "msg_4D_mkdir=Creating the installation folder."
set "msg_4D_InstallingRobo=Installing ROBOCOPY."
set "msg_4D_RoboCopyError=There was an error durring the update.  Please contact MIS."
set "msg_4D_RoboNotExistOnNet=ROBOCOPY is not available on the network!  Please contact MIS."
set "msg_4D_ROBOCOULDNTCOPY=ROBOCOPY could not be copy to the destination!  Please contact MIS."
set "msg_4D_Error=There was an error, please contact MIS"
set "msg_4D_MirrorUnaccessible=The mirror is not currently accessible; please try again in a little while or contact MIS"


REM general file paths
set "ROBOCOPYXP=\\server\share\to\robocopy\robocopyXP.exe"
set "ROBOCOPYBIN=%USERPROFILE%\robocopy.exe" 
set "_4D_admin_log=%USERPROFILE%\4D_admin.log"
set "_4D_mirror_log=%USERPROFILE%\4D_mirror.log"

REM 32 bit specific declarations
set "_4D_32_install=%USERPROFILE%\Program Files\4D\4D_Client"
set "_4D_32_mirror=\\server\share\to\4D_Win"

REM 64 bit specific declarations
set "_4D_64_install=%USERPROFILE%\Program Files (x86)\4D\4D_Client"
set "_4D_64_mirror=\\server\share\to\4D_Win"


REM initiate log file
echo ADMIN: Last update started on %DATE% @ %TIME% > "%_4D_admin_log%"  2>&1

REM check for 64 bit machines
IF "%PROCESSOR_ARCHITECTURE%"=="x86" (
	REM system is a 32 bit machine
	echo ADMIN: You are running a 32 bit machine >> "%_4D_admin_log%"  2>&1
	SET "_4D_install=%_4D_32_install%"
	SET "_4D_mirror=%_4D_32_mirror%"
	goto INSTALL
) ELSE IF "%PROCESSOR_ARCHITECTURE%"=="ia64" (
	REM system has an Itanium processor
	REM 4D is not compatible with ia64 processors
	echo Please notify the MIS deparment that you are using an ia64 processor >> "%_4D_admin_log%"  2>&1
	goto Error
) ELSE (
	REM system is a 64 bit machine
	echo ADMIN: You are running a 64 bit machine >> "%_4D_admin_log%"  2>&1
	SET "_4D_install=%_4D_64_install%"
	SET "_4D_mirror=%_4D_64_mirror%"
	goto INSTALL
)

REM prelim check for robocopy
if EXIST "%windir%\system32\robocopy.exe" set "ROBOCOPYBIN=%windir%\system32\robocopy.exe" 


:INSTALL
REM check if installation path exists
if NOT EXIST "%_4D_install%" (
	echo %msg_4D_mkdir%
	echo ADMIN: %msg_4D_mkdir% >> "%_4D_admin_log%"  2>&1
	mkdir "%_4D_install%"
	echo ADMIN: mkdir errorlevel = %ERRORLEVEL% >> "%_4D_admin_log%"  2>&1
)
if NOT EXIST "%_4D_install%" (
	echo could not create directory!!! "%_4D_install%" 
	echo ADMIN: could not create directory!!! "%_4D_install%" >> "%_4D_admin_log%"  2>&1
)


REM check if mirror folder is accessible
IF NOT EXIST %_4D_mirror% goto MirrorUnaccessible

 
REM check for ROBOCOPY
if EXIST "%ROBOCOPYBIN%" (
	REM ROBOCOPY exists so mirror the folder
	REM go run robocopy
	goto RoboRunner
) ELSE (
	REM ROBOCOPY doesnt exist so first check if it exists on the network
	IF NOT EXIST "%ROBOCOPYXP%" GOTO ROBONOTEXISTONNET
	
	REM ROBOCOPY exists on the network so lets copy it to the system
	echo %msg_4D_InstallingRobo%
	echo ADMIN: Getting ROBOCOPY from  "%ROBOCOPYXP%" >> "%_4D_admin_log%" 2>&1
	echo ADMIN: Copying "%ROBOCOPYXP%" to "%ROBOCOPYBIN%" >> "%_4D_admin_log%" 2>&1
	copy "%ROBOCOPYXP%" "%ROBOCOPYBIN%"
	
	REM check to see if it copied correctly
	IF NOT EXIST "%ROBOCOPYXP%" GOTO ROBOCOULDNTCOPY

	REM it copied correctly so mirror 4D version
	goto RoboRunner
)


:RoboRunner
REM run robocopy
echo %msg_4D_GetNew4D%
echo ADMIN: %msg_4D_GetNew4D% >> "%_4D_admin_log%"  2>&1
echo ADMIN: Running ROBOCOPY from "%ROBOCOPYBIN%" with the following command >> "%_4D_admin_log%"  2>&1
echo ADMIN: "%ROBOCOPYBIN%" "%_4D_mirror%" "%_4D_install%" /mir /tee /r:3 /w:1 /LOG:"%_4D_mirror_log%" >> "%_4D_admin_log%"  2>&1
"%ROBOCOPYBIN%" "%_4D_mirror%" "%_4D_install%" /mir /tee /r:3 /w:1 /LOG:"%_4D_mirror_log%"
goto roboErrorHandler
	
:roboErrorHandler
if errorlevel 16 (
	echo ***FATAL ERROR***  >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 15 (
	echo FAIL MISM XTRA COPY  >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 14 (
	echo FAIL MISM XTRA  >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 13 (
	echo FAIL MISM COPY  >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 12 (
	echo FAIL MISM  >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 11 (
	echo FAIL XTRA COPY  >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 10 (
	echo FAIL XTRA  >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 9 (
	echo FAIL COPY >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 8 (
	echo FAIL >> "%_4D_admin_log%"  2>&1
	goto RoboCopyError
	)
if errorlevel 7 (
	echo %msg_4D_GetNew4Dfinished% (Mismatched, Extras deleted, Copied new files)
	echo %msg_4D_GetNew4Dfinished% (Mismatched, Extras deleted, Copied new files) >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
if errorlevel 6 (
	echo %msg_4D_GetNew4Dfinished% (Mismatched, Extras deleted)
	echo %msg_4D_GetNew4Dfinished% (Mismatched, Extras deleted) >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
if errorlevel 5 (
	echo %msg_4D_GetNew4Dfinished% (Mismatched, Copied new files)
	echo %msg_4D_GetNew4Dfinished% (Mismatched, Copied new files) >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
if errorlevel 4 (
	echo %msg_4D_GetNew4Dfinished% (Mismatch)
	echo %msg_4D_GetNew4Dfinished% (Mismatch) >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
if errorlevel 3 (
	echo %msg_4D_GetNew4Dfinished% (Extras deleted, Copied new files)
	echo %msg_4D_GetNew4Dfinished% (Extras deleted, Copied new files) >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
if errorlevel 2 (
	echo %msg_4D_GetNew4Dfinished% (Extras deleted)
	echo %msg_4D_GetNew4Dfinished% (Extras deleted) >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
if errorlevel 1 (
	echo %msg_4D_GetNew4Dfinished% (Copied new files) 
	echo %msg_4D_GetNew4Dfinished% (Copied new files)  >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
if errorlevel 0(
	echo %msg_4D_GetNew4Dfinished% (no changes) 
	echo %msg_4D_GetNew4Dfinished% (no changes)  >> "%_4D_admin_log%"  2>&1
	goto Launch4D
	)
goto END


:Launch4D
REM Launching 4D 
echo Launching 4D from "%_4D_install%\4D.exe"
echo ADMIN: Launching 4D from "%_4D_install%\4D.exe" >> "%_4D_admin_log%"  2>&1
start "" "%_4D_install%\4D.exe"
goto END

:ROBONOTEXISTONNET
echo %msg_4D_RoboNotExistOnNet%
echo %msg_4D_RoboNotExistOnNet% >> "%_4D_admin_log%"  2>&1
echo ADMIN: Reached error at %DATE% %TIME% >> "%_4D_admin_log%"  2>&1
pause
goto end

:ROBOCOULDNTCOPY
echo %msg_4D_ROBOCOULDNTCOPY%
echo %msg_4D_ROBOCOULDNTCOPY% >> "%_4D_admin_log%"  2>&1
echo ADMIN: Reached error at %DATE% %TIME% >> "%_4D_admin_log%"  2>&1
pause
goto END

:RoboCopyError
echo %msg_4D_RoboCopyError%
echo %msg_4D_RoboCopyError% >> "%_4D_admin_log%"  2>&1
echo ADMIN: Reached error at %DATE% %TIME% >> "%_4D_admin_log%"  2>&1
pause
goto end


:Error
echo %msg_4D_Error%
echo %msg_4D_Error% >> "%_4D_admin_log%"  2>&1
echo ADMIN: Reached error at %DATE% %TIME% >> "%_4D_admin_log%"  2>&1
pause
goto end

:MirrorUnaccessible
echo %msg_4D_MirrorUnaccessible% 
echo %msg_4D_MirrorUnaccessible% >> "%_4D_admin_log%"  2>&1
echo ADMIN: Reached error at %DATE% %TIME% >> "%_4D_admin_log%"  2>&1
pause
goto end


:END
echo ADMIN: Reached end of bat at %DATE% %TIME% >> "%_4D_admin_log%"  2>&1
@ECHO ON
exit